#pragma once
#include "deps/glm/glm.hpp"
#include "deps/cppcodec/base64_rfc4648.hpp"
#include <vector>
#include <iostream>
#include <memory>

using tvec3 = glm::highp_f32vec3;
using tvec2 = glm::highp_f32vec2;
using tfloat = float;

